@@ -11,16 +11,31 @@ static PyObject *method_fprintf(PyObject *self, PyObject *args) {
         return NULL;
     }
 
-    if (strlen(str) <= 0) {
+    /* Get length of input string */
+    Py_ssize_t str_len = PyUnicode_GET_LENGTH((PyObject*)str);
+
+    if (str_len <= 0) {
         /* Passing custom exception */
         PyErr_SetString(StringTooShortError, "String param must be exists");
         return NULL;
     }
 
     FILE *fp = fopen(filename, "w");
-    bytes_copied = fprintf(fp, str);
+    if (fp == NULL) {
+        /* Handle file opening error */
+        PyErr_SetString(PyExc_IOError, "Unable to open file");
+        return NULL;
+    }
+
+    bytes_copied = fprintf(fp, "%s", str);
     fclose(fp);
 
+    if (bytes_copied < 0) {
+        /* Handle fprintf error */
+        PyErr_SetString(PyExc_IOError, "Unable to write to file");
+        return NULL;
+    }
+
     return PyLong_FromLong(bytes_copied);
 }
 
